@@ -1,5 +1,3 @@
-require 'addressable/uri'
-require 'simple_oauth'
 require 'twitter/error'
 require 'twitter/utils'
 require 'twitter/version'
@@ -20,10 +18,10 @@ module Twitter
     # @return [Twitter::Client]
     def initialize(options = {})
       options.each do |key, value|
-        send(:"#{key}=", value)
+        instance_variable_set("@#{key}", value)
       end
       yield(self) if block_given?
-      validate_credential_type!
+      validate_credentials!
     end
 
     # @return [Boolean]
@@ -33,16 +31,17 @@ module Twitter
 
     # @return [String]
     def user_agent
-      @user_agent ||= "Twitter Ruby Gem #{Twitter::Version}"
+      @user_agent ||= "TwitterRubyGem/#{Twitter::Version}"
     end
 
     # @return [Hash]
     def credentials
       {
-        :consumer_key    => consumer_key,
-        :consumer_secret => consumer_secret,
-        :token           => access_token,
-        :token_secret    => access_token_secret,
+        consumer_key: consumer_key,
+        consumer_secret: consumer_secret,
+        token: access_token,
+        token_secret: access_token_secret,
+        ignore_extra_keys: true,
       }
     end
 
@@ -54,20 +53,15 @@ module Twitter
   private
 
     # Ensures that all credentials set during configuration are of a
-    # valid type. Valid types are String and Symbol.
+    # valid type. Valid types are String and Boolean.
     #
     # @raise [Twitter::Error::ConfigurationError] Error is raised when
-    #   supplied twitter credentials are not a String or Symbol.
-    def validate_credential_type!
+    #   supplied twitter credentials are not a String or Boolean.
+    def validate_credentials!
       credentials.each do |credential, value|
-        next if value.nil?
-        fail(Twitter::Error::ConfigurationError.new("Invalid #{credential} specified: #{value.inspect} must be a string or symbol.")) unless value.is_a?(String) || value.is_a?(Symbol)
+        next if value.nil? || value == true || value == false || value.is_a?(String)
+        raise(Twitter::Error::ConfigurationError.new("Invalid #{credential} specified: #{value.inspect} must be a String."))
       end
     end
-
-    def oauth_auth_header(method, uri, params = {})
-      uri = Addressable::URI.parse(uri)
-      SimpleOAuth::Header.new(method, uri, params, credentials)
-    end
   end
 end
