@@ -50,13 +50,8 @@ module Twitter
     #
     # @return [String]
     def bearer_token_credentials_auth_header
-      basic_auth_token = strict_encode64("#{@client.consumer_key}:#{@client.consumer_secret}")
+      basic_auth_token = Base64.strict_encode64("#{@client.consumer_key}:#{@client.consumer_secret}")
       "Basic #{basic_auth_token}"
     end
-
-    # Base64.strict_encode64 is not available on Ruby 1.8.7
-    def strict_encode64(str)
-      Base64.encode64(str).delete("\n")
-    end
   end
 end
