@@ -1,8 +1,11 @@
+require 'memoizable'
 require 'twitter/identity'
 
 module Twitter
   module Media
     class Photo < Twitter::Identity
+      include Memoizable
+
       # @return [Array<Integer>]
       attr_reader :indices
       display_uri_attr_reader
@@ -12,9 +15,8 @@ module Twitter
       #
       # @return [Array<Twitter::Size>]
       def sizes
-        @attrs.fetch(:sizes, []).inject({}) do |object, (key, value)|
+        @attrs.fetch(:sizes, []).each_with_object({}) do |(key, value), object|
           object[key] = Size.new(value)
-          object
         end
       end
       memoize :sizes
