@@ -9,22 +9,21 @@ module Twitter
     config.define_implicit_conversions
     config.predicates_return false
 
-    # TODO: Add when support for Ruby 1.8.7 is dropped
-    # def !
-    #   true
-    # end
+    def !
+      true
+    end
 
     def respond_to?(*)
       true
     end
 
     def instance_of?(klass)
-      fail(TypeError.new('class or module required')) unless klass.is_a?(Class)
+      raise(TypeError.new('class or module required')) unless klass.is_a?(Class)
       self.class == klass
     end
 
     def kind_of?(mod)
-      fail(TypeError.new('class or module required')) unless mod.is_a?(Module)
+      raise(TypeError.new('class or module required')) unless mod.is_a?(Module)
       self.class.ancestors.include?(mod)
     end
 
@@ -41,5 +40,13 @@ module Twitter
     def nil?
       true
     end
+
+    def as_json(*)
+      'null'
+    end
+
+    def to_json(*args)
+      nil.to_json(*args)
+    end
   end
 end
