@@ -1,14 +1,19 @@
-require 'equalizer'
+require 'memoizable'
 require 'twitter/identity'
 
 module Twitter
   class Place < Twitter::Identity
-    attr_reader :attributes, :country, :full_name, :name
-    alias_method :woe_id, :id
-    alias_method :woeid, :id
+    include Memoizable
+
+    # @return [Hash]
+    attr_reader :attributes
+    # @return [String]
+    attr_reader :country, :full_name, :name
+    alias woe_id id
+    alias woeid id
     object_attr_reader :GeoFactory, :bounding_box
     object_attr_reader :Place, :contained_within
-    alias_method :contained?, :contained_within?
+    alias contained? contained_within?
     uri_attr_reader :uri
 
     # Initializes a new place
@@ -23,7 +28,7 @@ module Twitter
 
     # @return [String]
     def country_code
-      @attrs[:country_code] || @attrs[:countryCode] # rubocop:disable SymbolName
+      @attrs[:country_code] || @attrs[:countryCode]
     end
     memoize :country_code
 
@@ -35,7 +40,7 @@ module Twitter
 
     # @return [String]
     def place_type
-      @attrs[:place_type] || @attrs[:placeType] && @attrs[:placeType][:name] # rubocop:disable SymbolName
+      @attrs[:place_type] || @attrs[:placeType] && @attrs[:placeType][:name]
     end
     memoize :place_type
   end
