@@ -9,11 +9,8 @@ module Twitter
           status_code = response.status.to_i
           klass = Twitter::Error.errors[status_code]
           return unless klass
-          if klass == Twitter::Error::Forbidden
-            fail(handle_forbidden_errors(response))
-          else
-            fail(klass.from_response(response))
-          end
+          raise(handle_forbidden_errors(response)) if klass == Twitter::Error::Forbidden
+          raise(klass.from_response(response))
         end
 
       private
@@ -32,4 +29,4 @@ module Twitter
   end
 end
 
-Faraday::Response.register_middleware :twitter_raise_error => Twitter::REST::Response::RaiseError
+Faraday::Response.register_middleware twitter_raise_error: Twitter::REST::Response::RaiseError
