@@ -8,9 +8,9 @@ module Twitter
     module Trends
       include Twitter::REST::Utils
 
-      # Returns the top 10 trending topics for a specific WOEID
+      # Returns the top 50 trending topics for a specific WOEID
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/trends/place
+      # @see https://dev.twitter.com/rest/reference/get/trends/place
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -23,12 +23,12 @@ module Twitter
         response = perform_get('/1.1/trends/place.json', options).first
         Twitter::TrendResults.new(response)
       end
-      alias_method :local_trends, :trends
-      alias_method :trends_place, :trends
+      alias local_trends trends
+      alias trends_place trends
 
       # Returns the locations that Twitter has trending topic information for
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/trends/available
+      # @see https://dev.twitter.com/rest/reference/get/trends/available
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -37,11 +37,11 @@ module Twitter
       def trends_available(options = {})
         perform_get_with_objects('/1.1/trends/available.json', options, Twitter::Place)
       end
-      alias_method :trend_locations, :trends_available
+      alias trend_locations trends_available
 
       # Returns the locations that Twitter has trending topic information for, closest to a specified location.
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/trends/closest
+      # @see https://dev.twitter.com/rest/reference/get/trends/closest
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
