@@ -1,4 +1,7 @@
 require 'buftok'
+require 'http'
+require 'json'
+require 'twitter/error'
 
 module Twitter
   module Streaming
@@ -18,13 +21,13 @@ module Twitter
 
       def on_headers_complete(_headers)
         error = Twitter::Error.errors[@parser.status_code]
-        fail error.new if error
+        raise error.new if error
       end
 
       def on_body(data)
         @tokenizer.extract(data).each do |line|
           next if line.empty?
-          @block.call(JSON.parse(line, :symbolize_names => true))
+          @block.call(JSON.parse(line, symbolize_names: true))
         end
       end
     end
