@@ -4,12 +4,12 @@ module Twitter
 
     # @return [Integer]
     def major
-      5
+      6
     end
 
     # @return [Integer]
     def minor
-      16
+      1
     end
 
     # @return [Integer]
@@ -25,10 +25,10 @@ module Twitter
     # @return [Hash]
     def to_h
       {
-        :major => major,
-        :minor => minor,
-        :patch => patch,
-        :pre => pre,
+        major: major,
+        minor: minor,
+        patch: patch,
+        pre: pre,
       }
     end
 
