@@ -1,5 +1,14 @@
 require 'simplecov'
 require 'coveralls'
+
+SimpleCov.formatters = [SimpleCov::Formatter::HTMLFormatter, Coveralls::SimpleCov::Formatter]
+
+SimpleCov.start do
+  add_filter '/spec/'
+  add_filter '/vendor/'
+  minimum_coverage(99.55)
+end
+
 require 'twitter'
 require 'rspec'
 require 'stringio'
@@ -7,7 +16,9 @@ require 'tempfile'
 require 'timecop'
 require 'webmock/rspec'
 
-WebMock.disable_net_connect!(:allow => 'coveralls.io')
+require File.expand_path('../support/media_object_examples', __FILE__)
+
+WebMock.disable_net_connect!(allow: 'coveralls.io')
 
 RSpec.configure do |config|
   config.expect_with :rspec do |c|
@@ -16,35 +27,35 @@ RSpec.configure do |config|
 end
 
 def a_delete(path)
-  a_request(:delete, Twitter::REST::Client::URL_PREFIX + path)
+  a_request(:delete, Twitter::REST::Client::BASE_URL + path)
 end
 
 def a_get(path)
-  a_request(:get, Twitter::REST::Client::URL_PREFIX + path)
+  a_request(:get, Twitter::REST::Client::BASE_URL + path)
 end
 
 def a_post(path)
-  a_request(:post, Twitter::REST::Client::URL_PREFIX + path)
+  a_request(:post, Twitter::REST::Client::BASE_URL + path)
 end
 
 def a_put(path)
-  a_request(:put, Twitter::REST::Client::URL_PREFIX + path)
+  a_request(:put, Twitter::REST::Client::BASE_URL + path)
 end
 
 def stub_delete(path)
-  stub_request(:delete, Twitter::REST::Client::URL_PREFIX + path)
+  stub_request(:delete, Twitter::REST::Client::BASE_URL + path)
 end
 
 def stub_get(path)
-  stub_request(:get, Twitter::REST::Client::URL_PREFIX + path)
+  stub_request(:get, Twitter::REST::Client::BASE_URL + path)
 end
 
 def stub_post(path)
-  stub_request(:post, Twitter::REST::Client::URL_PREFIX + path)
+  stub_request(:post, Twitter::REST::Client::BASE_URL + path)
 end
 
 def stub_put(path)
-  stub_request(:put, Twitter::REST::Client::URL_PREFIX + path)
+  stub_request(:put, Twitter::REST::Client::BASE_URL + path)
 end
 
 def fixture_path
