@@ -2,7 +2,7 @@ require 'helper'
 
 describe Twitter::Base do
   before do
-    @base = Twitter::Base.new(:id => 1)
+    @base = Twitter::Base.new(id: 1)
   end
 
   describe '#[]' do
@@ -26,14 +26,22 @@ describe Twitter::Base do
       warning = capture_warning do
         @base[:object_id]
       end
-      expect(warning).to match(/\[DEPRECATION\] #\[:object_id\] is deprecated. Use #object_id to fetch the value./)
+      expect(warning).to match(/\[DEPRECATION\] #\[:object_id\] is deprecated\. Use #object_id to fetch the value\./)
     end
   end
 
   describe '#attrs' do
     it 'returns a hash of attributes' do
-      expect(@base.attrs).to eq(:id => 1)
+      expect(@base.attrs).to eq(id: 1)
     end
   end
 
+  describe '#to_hsh' do
+    it 'outputs a warning' do
+      warning = capture_warning do
+        expect(@base.to_hsh).to eq(id: 1)
+      end
+      expect(warning).to match(/\[DEPRECATION\] #to_hsh is deprecated\. Use #to_hash instead\./)
+    end
+  end
 end
