@@ -2,10 +2,9 @@
 require 'helper'
 
 describe Twitter::Entity::URI do
-
   describe '#display_uri' do
     it 'returns a String when the display_url is set' do
-      uri = Twitter::Entity::URI.new(:display_url => 'example.com/expanded…')
+      uri = Twitter::Entity::URI.new(display_url: 'example.com/expanded…')
       expect(uri.display_uri).to be_a String
       expect(uri.display_uri).to eq('example.com/expanded…')
     end
@@ -17,7 +16,7 @@ describe Twitter::Entity::URI do
 
   describe '#display_uri?' do
     it 'returns true when the display_url is set' do
-      uri = Twitter::Entity::URI.new(:display_url => 'example.com/expanded…')
+      uri = Twitter::Entity::URI.new(display_url: 'example.com/expanded…')
       expect(uri.display_uri?).to be true
     end
     it 'returns false when the display_url is not set' do
@@ -28,7 +27,7 @@ describe Twitter::Entity::URI do
 
   describe '#expanded_uri' do
     it 'returns a URI when the expanded_url is set' do
-      uri = Twitter::Entity::URI.new(:expanded_url => 'https://github.com/sferik')
+      uri = Twitter::Entity::URI.new(expanded_url: 'https://github.com/sferik')
       expect(uri.expanded_uri).to be_an Addressable::URI
       expect(uri.expanded_uri.to_s).to eq('https://github.com/sferik')
     end
@@ -40,7 +39,7 @@ describe Twitter::Entity::URI do
 
   describe '#expanded_uri?' do
     it 'returns true when the expanded_url is set' do
-      uri = Twitter::Entity::URI.new(:expanded_url => 'https://github.com/sferik')
+      uri = Twitter::Entity::URI.new(expanded_url: 'https://github.com/sferik')
       expect(uri.expanded_uri?).to be true
     end
     it 'returns false when the expanded_url is not set' do
@@ -51,7 +50,7 @@ describe Twitter::Entity::URI do
 
   describe '#uri' do
     it 'returns a URI when the url is set' do
-      uri = Twitter::Entity::URI.new(:url => 'https://github.com/sferik')
+      uri = Twitter::Entity::URI.new(url: 'https://github.com/sferik')
       expect(uri.uri).to be_an Addressable::URI
       expect(uri.uri.to_s).to eq('https://github.com/sferik')
     end
@@ -63,7 +62,7 @@ describe Twitter::Entity::URI do
 
   describe '#uri?' do
     it 'returns true when the url is set' do
-      uri = Twitter::Entity::URI.new(:url => 'https://github.com/sferik')
+      uri = Twitter::Entity::URI.new(url: 'https://github.com/sferik')
       expect(uri.uri?).to be true
     end
     it 'returns false when the url is not set' do
@@ -71,5 +70,4 @@ describe Twitter::Entity::URI do
       expect(uri.uri?).to be false
     end
   end
-
 end
