@@ -1,10 +1,9 @@
 require 'helper'
 
 describe Twitter::Token do
-
   describe '#bearer?' do
     it 'returns true when token is a bearer token' do
-      token = Twitter::Token.new(:token_type => 'bearer')
+      token = Twitter::Token.new(token_type: 'bearer')
       expect(token.bearer?).to be true
     end
     it 'returns false when token type is nil' do
@@ -12,5 +11,4 @@ describe Twitter::Token do
       expect(token.bearer?).to be false
     end
   end
-
 end
